@@ -1,6 +1,6 @@
 =head1 NAME
 
-Coro::Handle - non-blocking io with a blocking interface.
+Coro::Handle - non-blocking I/O with a blocking interface.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ use AnyEvent::Util qw(WSAEWOULDBLOCK WSAEINPROGRESS);
 
 use base 'Exporter';
 
-our $VERSION = "5.0";
+our $VERSION = 5.1;
 our @EXPORT = qw(unblock);
 
 =item $fh = new_from_fh Coro::Handle $fhandle [, arg => value...]
@@ -263,6 +263,8 @@ use Errno qw(EAGAIN EINTR);
 use AnyEvent ();
 use AnyEvent::Util qw(WSAEWOULDBLOCK);
 
+use Coro::AnyEvent;
+
 # formerly a hash, but we are speed-critical, so try
 # to be faster even if it hurts.
 #
@@ -271,8 +273,8 @@ use AnyEvent::Util qw(WSAEWOULDBLOCK);
 # 2 timeout
 # 3 rb
 # 4 wb # unused
-# 5 read watcher, if Coro::Event used
-# 6 write watcher, if Coro::Event used
+# 5 read watcher, if Coro::Event|EV used
+# 6 write watcher, if Coro::Event|EV used
 # 7 forward class
 # 8 blocking
 
@@ -294,8 +296,10 @@ sub TIEHANDLE {
 }
 
 sub cleanup {
-   $_[0][5]->cancel if $_[0][5];
-   $_[0][6]->cancel if $_[0][6];
+   eval {
+      $_[0][5]->cancel if $_[0][5];
+      $_[0][6]->cancel if $_[0][6];
+   };
    @{$_[0]} = ();
 }
 
@@ -363,56 +367,47 @@ sub FETCH {
 }
 
 sub readable_anyevent {
-   my $current = $Coro::current;
+   my $cb = Coro::rouse_cb;
    my $io = 1;
 
    my $w = AnyEvent->io (
       fh    => $_[0][0],
       poll  => 'r',
-      cb    => sub {
-         $current->ready if $current;
-         undef $current;
-      },
+      cb    => $cb,
    );
 
    my $t = (defined $_[0][2]) && AnyEvent->timer (
       after => $_[0][2],
       cb    => sub {
          $io = 0;
-         $current->ready if $current;
-         undef $current;
+         $cb->();
       },
    );
 
-   &Coro::schedule;
-   &Coro::schedule while $current;
+   Coro::rouse_wait;
 
    $io
 }
 
 sub writable_anyevent {
-   my $current = $Coro::current;
+   my $cb = Coro::rouse_cb;
    my $io = 1;
 
    my $w = AnyEvent->io (
       fh    => $_[0][0],
       poll  => 'w',
-      cb    => sub {
-         $current->ready if $current;
-         undef $current;
-      },
+      cb    => $cb,
    );
 
    my $t = (defined $_[0][2]) && AnyEvent->timer (
       after => $_[0][2],
       cb    => sub {
          $io = 0;
-         $current->ready if $current;
-         undef $current;
+         $cb->();
       },
    );
 
-   &Coro::schedule while $current;
+   Coro::rouse_wait;
 
    $io
 }
